==> qt5-base-debuginfo-5.4.2-2.tar.xz: usr/src/debug/qt5-base-5.4.2-2/examples/widgets/widgets/validators/.rcc/qrc_validators.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.4.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-base/qt5-base-5.4.2-2.i686/src/qtbase-opensource-src-5.4.2/examples/widgets/widgets/validators/ledoff.png
  0x0,0x0,0x2,0x32,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x16,0x0,0x0,0x0,0x16,0x8,0x6,0x0,0x0,0x0,0xc4,0xb4,0x6c,0x3b,
  0x0,0x0,0x0,0x4,0x73,0x42,0x49,0x54,0x8,0x8,0x8,0x8,0x7c,0x8,0x64,0x88,
  0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x53,0x6f,0x66,0x74,0x77,0x61,0x72,0x65,
  0x0,0x77,0x77,0x77,0x2e,0x69,0x6e,0x6b,0x73,0x63,0x61,0x70,0x65,0x2e,0x6f,0x72,
  0x67,0x9b,0xee,0x3c,0x1a,0x0,0x0,0x1,0xc4,0x49,0x44,0x41,0x54,0x38,0xcb,0xad,
  0xd5,0x4d,0x2f,0x3,0x41,0x18,0x7,0xf0,0xf9,0x4,0x9b,0xec,0xb7,0xda,0xdb,0x7e,
  0x14,0xef,0x4,0x5d,0xed,0xf6,0x85,0xa5,0x28,0x11,0x41,0x9c,0xd8,0xd2,0xa2,0x2d,
  0x53,0x5a,0x2f,0xe1,0x42,0xeb,0xe0,0x80,0x1b,0x71,0xe2,0xb0,0x69,0x7c,0x8a,0xc7,
  0xff,0x59,0x2b,0x4a,0x77,0xb7,0x2f,0xe9,0xe1,0x97,0x6c,0x66,0xe6,0xf9,0x67,0xb2,
  0x99,0x79,0x46,0x10,0x91,0xf0,0x33,0xbc,0x3b,0xa0,0x80,0x6,0x6,0x48,0x70,0x3c,
  0xd2,0x1b,0xe3,0x39,0x25,0xa8,0x3e,0x28,0x54,0x37,0xf2,0x93,0x9f,0xf6,0xed,0xe,
  0x55,0x9f,0xce,0xa8,0xf6,0x72,0x47,0xcf,0xef,0x4f,0x2e,0xfe,0xe6,0x31,0x9e,0x9b,
  0xc6,0x1a,0x5e,0xdb,0x36,0x78,0xd4,0x1e,0x52,0x93,0x45,0xb3,0x90,0xab,0xef,0x53,
  0xfd,0xb5,0x46,0xf7,0x6f,0xf7,0x1,0xea,0xae,0xda,0xeb,0x1d,0xe5,0xea,0x7b,0x14,
  0x2f,0xc6,0xa,0x23,0xf6,0xa0,0xea,0x1b,0x3c,0x9e,0x1d,0x51,0xe3,0x85,0xa8,0x73,
  0xf2,0x50,0xa2,0xea,0xe3,0x59,0x47,0x2a,0x1e,0xae,0x31,0x51,0x3b,0x86,0x8c,0x96,
  0xe0,0xe8,0x61,0x24,0x9f,0xbd,0xdd,0x25,0xde,0x6d,0x7b,0x7b,0xff,0x64,0x29,0x8b,
  0x5f,0x13,0x3d,0x88,0xe4,0xff,0x4,0x4f,0xe5,0x26,0x74,0xeb,0x24,0x45,0xdb,0x37,
  0x5b,0x5d,0xda,0xfc,0x75,0xbd,0x49,0x9c,0xc1,0x59,0x6e,0x70,0x24,0x3f,0xa9,0x40,
  0x23,0x5d,0x9e,0xa7,0xd5,0x6a,0xa6,0x23,0x2b,0x1,0xd2,0xd2,0x22,0xce,0xe2,0x4c,
  0x31,0x73,0x38,0xad,0x1,0xa5,0x8e,0x4d,0x5a,0x28,0x5b,0x30,0x17,0xc2,0xa,0x95,
  0x2c,0x99,0xc4,0x59,0x9c,0x29,0x62,0x47,0x33,0x6,0x50,0xec,0x28,0x4a,0xa9,0x52,
  0xa2,0x49,0x3c,0x44,0xc2,0xd7,0x77,0x8e,0xc1,0xc,0x81,0xa3,0x22,0x81,0x7e,0x24,
  0x4a,0xff,0x14,0x9b,0x14,0x4c,0x1f,0x31,0x17,0x4e,0x54,0x33,0x29,0xb0,0x3,0x27,
  0x89,0x5d,0xfc,0x48,0x14,0xcd,0x9e,0x34,0x67,0x80,0x23,0xe6,0x8e,0x93,0xe,0x10,
  0x9b,0xed,0x1f,0x47,0xcc,0xcb,0x59,0x9,0xd4,0x2d,0x2b,0x9c,0x14,0xe9,0xb2,0x65,
  0x0,0xf5,0x2a,0xe0,0x84,0x18,0x62,0xe9,0x74,0x41,0x3,0xea,0x33,0x4d,0x64,0x2a,
  0x4b,0xa,0x34,0x80,0x32,0x95,0xc5,0x7e,0x40,0xd6,0xa2,0xe2,0x5e,0x69,0xdc,0x26,
  0xbd,0xd3,0x5b,0xf7,0x6d,0x39,0x8c,0xfe,0xa7,0x9,0xad,0x5d,0xac,0xda,0x40,0x5d,
  0x39,0x6f,0x61,0xb7,0x74,0xb7,0xf5,0xcb,0x35,0x15,0x3e,0x80,0x7a,0xc4,0xb5,0xaa,
  0x6f,0xa3,0xdf,0xb8,0x5a,0x57,0xc1,0x6,0xea,0x12,0xd7,0xa8,0x6d,0x9f,0xa6,0xad,
  0xeb,0xd,0x1d,0x1a,0x40,0x6d,0xf0,0x1a,0xbd,0xe3,0x37,0x8f,0xa1,0xdf,0x2a,0xa0,
  0x81,0x1,0x12,0x1c,0x8f,0xf4,0xc6,0x78,0x2e,0xf0,0x31,0xfd,0x2,0x30,0x9b,0x3e,
  0x64,0x2c,0xf4,0xaa,0x4f,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,
  0x82,
    // /usr/src/ports/qt5-base/qt5-base-5.4.2-2.i686/src/qtbase-opensource-src-5.4.2/examples/widgets/widgets/validators/ledon.png
  0x0,0x0,0x1,0xe6,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x16,0x0,0x0,0x0,0x16,0x8,0x6,0x0,0x0,0x0,0xc4,0xb4,0x6c,0x3b,
  0x0,0x0,0x0,0x4,0x73,0x42,0x49,0x54,0x8,0x8,0x8,0x8,0x7c,0x8,0x64,0x88,
  0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x53,0x6f,0x66,0x74,0x77,0x61,0x72,0x65,
  0x0,0x77,0x77,0x77,0x2e,0x69,0x6e,0x6b,0x73,0x63,0x61,0x70,0x65,0x2e,0x6f,0x72,
  0x67,0x9b,0xee,0x3c,0x1a,0x0,0x0,0x1,0x78,0x49,0x44,0x41,0x54,0x38,0xcb,0xad,
  0x95,0xb1,0x6a,0xc2,0x50,0x14,0x86,0xef,0xe6,0x16,0xcc,0xea,0x26,0x3e,0x82,0xa8,
  0xab,0x5b,0x2f,0x42,0x7b,0x85,0xb6,0xe,0x1d,0x6c,0xc1,0x82,0x50,0xc1,0xd6,0x59,
  0x33,0xd5,0xae,0xce,0x52,0x28,0x54,0x5c,0xa,0x16,0xca,0x1d,0x5c,0x9d,0x9d,0x7d,
  0x83,0xe,0x41,0xfa,0x14,0x7f,0xff,0x63,0x43,0x5b,0x35,0x36,0xb1,0x86,0x8f,0xf,
  0xc2,0xb9,0xe7,0xfc,0x9,0x9,0xb9,0x57,0x1,0x50,0x61,0xa6,0x90,0x72,0xa8,0xa6,
  0x1e,0xb5,0xd4,0xf,0xb4,0x41,0x4d,0xd6,0x9c,0x5d,0xf3,0xa1,0xc5,0x34,0xd2,0x26,
  0x8b,0xec,0x47,0x3,0xd,0xdc,0x93,0x47,0xf2,0x16,0x20,0xd7,0x52,0x93,0x35,0xe9,
  0x91,0xde,0xc8,0xe0,0xc,0x32,0x6e,0x1e,0xf9,0xd7,0x36,0xda,0x78,0x22,0xcf,0x11,
  0x48,0x8f,0xf4,0xca,0x8c,0xcc,0x86,0x6,0xe7,0x90,0x73,0xb,0x28,0xf8,0x3d,0xf4,
  0xf0,0x10,0x93,0x7e,0x80,0xcc,0xc8,0xac,0x64,0x6c,0x5,0x17,0x51,0x7c,0x69,0xa1,
  0x85,0xbb,0x18,0xdc,0x6e,0x20,0xb5,0x1b,0x22,0x19,0x6b,0xc1,0x25,0x94,0x8c,0x86,
  0xc6,0xd5,0x9e,0x5c,0x6e,0x70,0x44,0x24,0x6b,0x15,0x5c,0x46,0xd9,0xa1,0x4b,0x3,
  0x83,0xf3,0x98,0x9c,0xed,0x40,0x32,0x24,0x4b,0x32,0x55,0x5,0x15,0x4d,0x71,0x42,
  0xaa,0x11,0x98,0x8,0x8e,0x49,0xe5,0xb,0xad,0x78,0x27,0x4f,0xee,0x76,0x4a,0xaa,
  0x7,0x22,0x19,0xc1,0xd3,0x7b,0xaa,0x8e,0xba,0xa5,0x2b,0x2e,0x48,0x6d,0x83,0xdf,
  0xaf,0xa0,0xf6,0x7,0x32,0x5b,0xff,0xc1,0xaa,0x26,0x9a,0x3e,0xfd,0xe6,0x9a,0xec,
  0xfb,0x11,0x65,0xa6,0xb9,0x8e,0xaf,0x3a,0xe8,0xf8,0x34,0x69,0x7c,0xd5,0x45,0xd7,
  0xd2,0xa4,0xb1,0x8a,0x7f,0x8e,0xd7,0x47,0xe2,0x78,0x6a,0x80,0x81,0xa6,0x49,0xa3,
  0xd5,0x10,0x43,0x87,0x2e,0x69,0x52,0x48,0x96,0xb3,0xfa,0xa5,0x47,0x18,0x19,0x9a,
  0x14,0x66,0x6d,0x13,0x9a,0x60,0x32,0xa6,0x87,0x32,0xde,0xda,0xdd,0xa6,0x98,0xba,
  0xf4,0x9d,0xfe,0x17,0x99,0x75,0x43,0x37,0xfa,0x19,0x66,0x2e,0x1d,0xd3,0x7d,0x91,
  0x19,0x37,0xf2,0x68,0x9a,0x63,0x6e,0xe8,0x92,0x46,0x21,0x3d,0x26,0xf6,0x99,0x27,
  0x2e,0xb0,0x70,0xa8,0xa6,0x1e,0xb5,0xd4,0xf,0xb4,0x41,0x4d,0xd6,0x76,0x1e,0xa6,
  0x9f,0x3f,0x3a,0x71,0x60,0xef,0xac,0x5d,0x59,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,
  0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // ledoff.png
  0x0,0xa,
  0x5,0xc7,0x0,0x27,
  0x0,0x6c,
  0x0,0x65,0x0,0x64,0x0,0x6f,0x0,0x66,0x0,0x66,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
    // ledon.png
  0x0,0x9,
  0xb,0x61,0xb2,0x27,
  0x0,0x6c,
  0x0,0x65,0x0,0x64,0x0,0x6f,0x0,0x6e,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,
  // :/ledoff.png
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
  // :/ledon.png
  0x0,0x0,0x0,0x1a,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x2,0x36,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_validators)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_validators)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_validators)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_validators)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_validators)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_validators)(); }
   } dummy;
}

==> qt5-base-debuginfo-5.5.1-1.tar.xz: usr/src/debug/qt5-base-5.5.1-1/examples/widgets/widgets/validators/.rcc/qrc_validators.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.5.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-base/qt5-base-5.5.1-1.x86_64/src/qtbase-opensource-src-5.5.1/examples/widgets/widgets/validators/ledoff.png
  0x0,0x0,0x2,0x32,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x16,0x0,0x0,0x0,0x16,0x8,0x6,0x0,0x0,0x0,0xc4,0xb4,0x6c,0x3b,
  0x0,0x0,0x0,0x4,0x73,0x42,0x49,0x54,0x8,0x8,0x8,0x8,0x7c,0x8,0x64,0x88,
  0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x53,0x6f,0x66,0x74,0x77,0x61,0x72,0x65,
  0x0,0x77,0x77,0x77,0x2e,0x69,0x6e,0x6b,0x73,0x63,0x61,0x70,0x65,0x2e,0x6f,0x72,
  0x67,0x9b,0xee,0x3c,0x1a,0x0,0x0,0x1,0xc4,0x49,0x44,0x41,0x54,0x38,0xcb,0xad,
  0xd5,0x4d,0x2f,0x3,0x41,0x18,0x7,0xf0,0xf9,0x4,0x9b,0xec,0xb7,0xda,0xdb,0x7e,
  0x14,0xef,0x4,0x5d,0xed,0xf6,0x85,0xa5,0x28,0x11,0x41,0x9c,0xd8,0xd2,0xa2,0x2d,
  0x53,0x5a,0x2f,0xe1,0x42,0xeb,0xe0,0x80,0x1b,0x71,0xe2,0xb0,0x69,0x7c,0x8a,0xc7,
  0xff,0x59,0x2b,0x4a,0x77,0xb7,0x2f,0xe9,0xe1,0x97,0x6c,0x66,0xe6,0xf9,0x67,0xb2,
  0x99,0x79,0x46,0x10,0x91,0xf0,0x33,0xbc,0x3b,0xa0,0x80,0x6,0x6,0x48,0x70,0x3c,
  0xd2,0x1b,0xe3,0x39,0x25,0xa8,0x3e,0x28,0x54,0x37,0xf2,0x93,0x9f,0xf6,0xed,0xe,
  0x55,0x9f,0xce,0xa8,0xf6,0x72,0x47,0xcf,0xef,0x4f,0x2e,0xfe,0xe6,0x31,0x9e,0x9b,
  0xc6,0x1a,0x5e,0xdb,0x36,0x78,0xd4,0x1e,0x52,0x93,0x45,0xb3,0x90,0xab,0xef,0x53,
  0xfd,0xb5,0x46,0xf7,0x6f,0xf7,0x1,0xea,0xae,0xda,0xeb,0x1d,0xe5,0xea,0x7b,0x14,
  0x2f,0xc6,0xa,0x23,0xf6,0xa0,0xea,0x1b,0x3c,0x9e,0x1d,0x51,0xe3,0x85,0xa8,0x73,
  0xf2,0x50,0xa2,0xea,0xe3,0x59,0x47,0x2a,0x1e,0xae,0x31,0x51,0x3b,0x86,0x8c,0x96,
  0xe0,0xe8,0x61,0x24,0x9f,0xbd,0xdd,0x25,0xde,0x6d,0x7b,0x7b,0xff,0x64,0x29,0x8b,
  0x5f,0x13,0x3d,0x88,0xe4,0xff,0x4,0x4f,0xe5,0x26,0x74,0xeb,0x24,0x45,0xdb,0x37,
  0x5b,0x5d,0xda,0xfc,0x75,0xbd,0x49,0x9c,0xc1,0x59,0x6e,0x70,0x24,0x3f,0xa9,0x40,
  0x23,0x5d,0x9e,0xa7,0xd5,0x6a,0xa6,0x23,0x2b,0x1,0xd2,0xd2,0x22,0xce,0xe2,0x4c,
  0x31,0x73,0x38,0xad,0x1,0xa5,0x8e,0x4d,0x5a,0x28,0x5b,0x30,0x17,0xc2,0xa,0x95,
  0x2c,0x99,0xc4,0x59,0x9c,0x29,0x62,0x47,0x33,0x6,0x50,0xec,0x28,0x4a,0xa9,0x52,
  0xa2,0x49,0x3c,0x44,0xc2,0xd7,0x77,0x8e,0xc1,0xc,0x81,0xa3,0x22,0x81,0x7e,0x24,
  0x4a,0xff,0x14,0x9b,0x14,0x4c,0x1f,0x31,0x17,0x4e,0x54,0x33,0x29,0xb0,0x3,0x27,
  0x89,0x5d,0xfc,0x48,0x14,0xcd,0x9e,0x34,0x67,0x80,0x23,0xe6,0x8e,0x93,0xe,0x10,
  0x9b,0xed,0x1f,0x47,0xcc,0xcb,0x59,0x9,0xd4,0x2d,0x2b,0x9c,0x14,0xe9,0xb2,0x65,
  0x0,0xf5,0x2a,0xe0,0x84,0x18,0x62,0xe9,0x74,0x41,0x3,0xea,0x33,0x4d,0x64,0x2a,
  0x4b,0xa,0x34,0x80,0x32,0x95,0xc5,0x7e,0x40,0xd6,0xa2,0xe2,0x5e,0x69,0xdc,0x26,
  0xbd,0xd3,0x5b,0xf7,0x6d,0x39,0x8c,0xfe,0xa7,0x9,0xad,0x5d,0xac,0xda,0x40,0x5d,
  0x39,0x6f,0x61,0xb7,0x74,0xb7,0xf5,0xcb,0x35,0x15,0x3e,0x80,0x7a,0xc4,0xb5,0xaa,
  0x6f,0xa3,0xdf,0xb8,0x5a,0x57,0xc1,0x6,0xea,0x12,0xd7,0xa8,0x6d,0x9f,0xa6,0xad,
  0xeb,0xd,0x1d,0x1a,0x40,0x6d,0xf0,0x1a,0xbd,0xe3,0x37,0x8f,0xa1,0xdf,0x2a,0xa0,
  0x81,0x1,0x12,0x1c,0x8f,0xf4,0xc6,0x78,0x2e,0xf0,0x31,0xfd,0x2,0x30,0x9b,0x3e,
  0x64,0x2c,0xf4,0xaa,0x4f,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,
  0x82,
    // /usr/src/ports/qt5-base/qt5-base-5.5.1-1.x86_64/src/qtbase-opensource-src-5.5.1/examples/widgets/widgets/validators/ledon.png
  0x0,0x0,0x1,0xe6,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x16,0x0,0x0,0x0,0x16,0x8,0x6,0x0,0x0,0x0,0xc4,0xb4,0x6c,0x3b,
  0x0,0x0,0x0,0x4,0x73,0x42,0x49,0x54,0x8,0x8,0x8,0x8,0x7c,0x8,0x64,0x88,
  0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x53,0x6f,0x66,0x74,0x77,0x61,0x72,0x65,
  0x0,0x77,0x77,0x77,0x2e,0x69,0x6e,0x6b,0x73,0x63,0x61,0x70,0x65,0x2e,0x6f,0x72,
  0x67,0x9b,0xee,0x3c,0x1a,0x0,0x0,0x1,0x78,0x49,0x44,0x41,0x54,0x38,0xcb,0xad,
  0x95,0xb1,0x6a,0xc2,0x50,0x14,0x86,0xef,0xe6,0x16,0xcc,0xea,0x26,0x3e,0x82,0xa8,
  0xab,0x5b,0x2f,0x42,0x7b,0x85,0xb6,0xe,0x1d,0x6c,0xc1,0x82,0x50,0xc1,0xd6,0x59,
  0x33,0xd5,0xae,0xce,0x52,0x28,0x54,0x5c,0xa,0x16,0xca,0x1d,0x5c,0x9d,0x9d,0x7d,
  0x83,0xe,0x41,0xfa,0x14,0x7f,0xff,0x63,0x43,0x5b,0x35,0x36,0xb1,0x86,0x8f,0xf,
  0xc2,0xb9,0xe7,0xfc,0x9,0x9,0xb9,0x57,0x1,0x50,0x61,0xa6,0x90,0x72,0xa8,0xa6,
  0x1e,0xb5,0xd4,0xf,0xb4,0x41,0x4d,0xd6,0x9c,0x5d,0xf3,0xa1,0xc5,0x34,0xd2,0x26,
  0x8b,0xec,0x47,0x3,0xd,0xdc,0x93,0x47,0xf2,0x16,0x20,0xd7,0x52,0x93,0x35,0xe9,
  0x91,0xde,0xc8,0xe0,0xc,0x32,0x6e,0x1e,0xf9,0xd7,0x36,0xda,0x78,0x22,0xcf,0x11,
  0x48,0x8f,0xf4,0xca,0x8c,0xcc,0x86,0x6,0xe7,0x90,0x73,0xb,0x28,0xf8,0x3d,0xf4,
  0xf0,0x10,0x93,0x7e,0x80,0xcc,0xc8,0xac,0x64,0x6c,0x5,0x17,0x51,0x7c,0x69,0xa1,
  0x85,0xbb,0x18,0xdc,0x6e,0x20,0xb5,0x1b,0x22,0x19,0x6b,0xc1,0x25,0x94,0x8c,0x86,
  0xc6,0xd5,0x9e,0x5c,0x6e,0x70,0x44,0x24,0x6b,0x15,0x5c,0x46,0xd9,0xa1,0x4b,0x3,
  0x83,0xf3,0x98,0x9c,0xed,0x40,0x32,0x24,0x4b,0x32,0x55,0x5,0x15,0x4d,0x71,0x42,
  0xaa,0x11,0x98,0x8,0x8e,0x49,0xe5,0xb,0xad,0x78,0x27,0x4f,0xee,0x76,0x4a,0xaa,
  0x7,0x22,0x19,0xc1,0xd3,0x7b,0xaa,0x8e,0xba,0xa5,0x2b,0x2e,0x48,0x6d,0x83,0xdf,
  0xaf,0xa0,0xf6,0x7,0x32,0x5b,0xff,0xc1,0xaa,0x26,0x9a,0x3e,0xfd,0xe6,0x9a,0xec,
  0xfb,0x11,0x65,0xa6,0xb9,0x8e,0xaf,0x3a,0xe8,0xf8,0x34,0x69,0x7c,0xd5,0x45,0xd7,
  0xd2,0xa4,0xb1,0x8a,0x7f,0x8e,0xd7,0x47,0xe2,0x78,0x6a,0x80,0x81,0xa6,0x49,0xa3,
  0xd5,0x10,0x43,0x87,0x2e,0x69,0x52,0x48,0x96,0xb3,0xfa,0xa5,0x47,0x18,0x19,0x9a,
  0x14,0x66,0x6d,0x13,0x9a,0x60,0x32,0xa6,0x87,0x32,0xde,0xda,0xdd,0xa6,0x98,0xba,
  0xf4,0x9d,0xfe,0x17,0x99,0x75,0x43,0x37,0xfa,0x19,0x66,0x2e,0x1d,0xd3,0x7d,0x91,
  0x19,0x37,0xf2,0x68,0x9a,0x63,0x6e,0xe8,0x92,0x46,0x21,0x3d,0x26,0xf6,0x99,0x27,
  0x2e,0xb0,0x70,0xa8,0xa6,0x1e,0xb5,0xd4,0xf,0xb4,0x41,0x4d,0xd6,0x76,0x1e,0xa6,
  0x9f,0x3f,0x3a,0x71,0x60,0xef,0xac,0x5d,0x59,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,
  0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // ledoff.png
  0x0,0xa,
  0x5,0xc7,0x0,0x27,
  0x0,0x6c,
  0x0,0x65,0x0,0x64,0x0,0x6f,0x0,0x66,0x0,0x66,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
    // ledon.png
  0x0,0x9,
  0xb,0x61,0xb2,0x27,
  0x0,0x6c,
  0x0,0x65,0x0,0x64,0x0,0x6f,0x0,0x6e,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,
  // :/ledoff.png
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
  // :/ledon.png
  0x0,0x0,0x0,0x1a,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x2,0x36,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_validators)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_validators)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_validators)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_validators)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_validators)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_validators)(); }
   } dummy;
}
